@@ -1,3 +1,5 @@
+#define C_KINO_ANALYZER
+#define C_KINO_TOKEN
 #include "KinoSearch/Util/ToolSet.h"
 
 #include "KinoSearch/Analysis/Analyzer.h"
@@ -44,18 +46,18 @@ bool_t
 Analyzer_dump_equals(Analyzer *self, Obj *dump)
 {
     Hash *source = (Hash*)dump;
-    if (!OBJ_IS_A(dump, HASH)) return false;
+    if (!Obj_Is_A(dump, HASH)) return false;
     else {
         CharBuf *class_name = (CharBuf*)Hash_Fetch_Str(source, "_class", 6);
         if (!class_name) return false;
-        if (!CB_Equals(Obj_Get_Class_Name(self), (Obj*)class_name)) {
+        if (!CB_Equals(Analyzer_Get_Class_Name(self), (Obj*)class_name)) {
             return false;
         }
     }
     return true;
 }
 
-/* Copyright 2006-2009 Marvin Humphrey
+/* Copyright 2006-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
