@@ -1,7 +1,8 @@
+#define C_KINO_NOTSCORER
 #include "KinoSearch/Util/ToolSet.h"
 
 #include "KinoSearch/Search/NOTScorer.h"
-#include "KinoSearch/Schema.h"
+#include "KinoSearch/Plan/Schema.h"
 #include "KinoSearch/Search/Similarity.h"
 
 NOTScorer*
@@ -86,7 +87,7 @@ NOTScorer_score(NOTScorer *self)
     return 0.0f;
 }
 
-/* Copyright 2007-2009 Marvin Humphrey
+/* Copyright 2007-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
