@@ -1,8 +1,9 @@
+#define C_KINO_NOMATCHSCORER
 #include "KinoSearch/Util/ToolSet.h"
 
 #include "KinoSearch/Search/NoMatchScorer.h"
-#include "KinoSearch/Schema.h"
 #include "KinoSearch/Index/IndexReader.h"
+#include "KinoSearch/Plan/Schema.h"
 #include "KinoSearch/Search/Similarity.h"
 
 NoMatchScorer*
@@ -33,7 +34,7 @@ NoMatchScorer_advance(NoMatchScorer* self, i32_t target)
     return 0;
 }
 
-/* Copyright 2007-2009 Marvin Humphrey
+/* Copyright 2007-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
