@@ -3,55 +3,53 @@
 
 #include "KinoSearch/Search/PolySearcher.h"
 
-#include "KinoSearch/Doc/HitDoc.h"
+#include "KinoSearch/Document/HitDoc.h"
 #include "KinoSearch/Index/DocVector.h"
 #include "KinoSearch/Index/PolyReader.h"
-#include "KinoSearch/Schema.h"
-#include "KinoSearch/Search/HitCollector.h"
+#include "KinoSearch/Plan/Schema.h"
+#include "KinoSearch/Search/Collector.h"
 #include "KinoSearch/Search/HitQueue.h"
 #include "KinoSearch/Search/Query.h"
 #include "KinoSearch/Search/MatchDoc.h"
 #include "KinoSearch/Search/Matcher.h"
-#include "KinoSearch/Search/Searchable.h"
+#include "KinoSearch/Search/Searcher.h"
 #include "KinoSearch/Search/SortSpec.h"
 #include "KinoSearch/Search/TopDocs.h"
 #include "KinoSearch/Search/Compiler.h"
-#include "KinoSearch/Searcher.h"
-#include "KinoSearch/Util/I32Array.h"
 
 PolySearcher*
-PolySearcher_init(PolySearcher *self, Schema *schema, VArray *searchables)
+PolySearcher_init(PolySearcher *self, Schema *schema, VArray *searchers)
 {
-    const u32_t num_searchables = VA_Get_Size(searchables);
+    const u32_t num_searchers = VA_Get_Size(searchers);
     u32_t i;
-    i32_t *starts_array = MALLOCATE(num_searchables, i32_t);
+    i32_t *starts_array = (i32_t*)MALLOCATE(num_searchers * sizeof(i32_t));
     i32_t doc_max = 0;
 
-    Searchable_init((Searchable*)self, schema);
-    self->searchables = (VArray*)INCREF(searchables);
+    Searcher_init((Searcher*)self, schema);
+    self->searchers = (VArray*)INCREF(searchers);
     self->starts = NULL; /* Safe cleanup. */
 
-    for (i = 0; i < num_searchables; i++) {
-        Searchable *searchable 
-            = (Searchable*)ASSERT_IS_A(VA_Fetch(searchables, i), SEARCHABLE);
-        Schema *candidate    = Searchable_Get_Schema(searchable);
-        VTable *orig_vt      = Obj_Get_VTable(schema);
-        VTable *candidate_vt = Obj_Get_VTable(candidate);
+    for (i = 0; i < num_searchers; i++) {
+        Searcher *searcher 
+            = (Searcher*)CERTIFY(VA_Fetch(searchers, i), SEARCHER);
+        Schema *candidate    = Searcher_Get_Schema(searcher);
+        VTable *orig_vt      = Schema_Get_VTable(schema);
+        VTable *candidate_vt = Schema_Get_VTable(candidate);
 
-        /* Confirm that searchables all use the same schema. */
+        /* Confirm that searchers all use the same schema. */
         if (orig_vt != candidate_vt) {
             THROW(ERR, "Conflicting schemas: '%o', '%o'",
-                Obj_Get_Class_Name(schema), 
-                Obj_Get_Class_Name(candidate));
+                Schema_Get_Class_Name(schema), 
+                Schema_Get_Class_Name(candidate));
         }
 
         /* Derive doc_max and relative start offsets. */
         starts_array[i] = (i32_t)doc_max;
-        doc_max += Searchable_Doc_Max(searchable);
+        doc_max += Searcher_Doc_Max(searcher);
     }
 
     self->doc_max = doc_max;
-    self->starts  = I32Arr_new_steal(starts_array, num_searchables);
+    self->starts  = I32Arr_new_steal(starts_array, num_searchers);
 
     return self;
 }
@@ -59,7 +57,7 @@ PolySearcher_init(PolySearcher *self, Schema *schema, VArray *searchables)
 void
 PolySearcher_destroy(PolySearcher *self)
 {
-    DECREF(self->searchables);
+    DECREF(self->searchers);
     DECREF(self->starts);
     SUPER_DESTROY(self, POLYSEARCHER);
 }
@@ -69,10 +67,10 @@ PolySearcher_fetch_doc(PolySearcher *self, i32_t doc_id, float score,
                        i32_t offset)
 {
     u32_t       tick       = PolyReader_sub_tick(self->starts, doc_id);
-    Searchable *searchable = (Searchable*)VA_Fetch(self->searchables, tick);
+    Searcher   *searcher   = (Searcher*)VA_Fetch(self->searchers, tick);
     i32_t       start      = I32Arr_Get(self->starts, tick);
-    if (!searchable) { THROW(ERR, "Invalid doc id: %i32", doc_id); }
-    return Searchable_Fetch_Doc(searchable, doc_id - start, score, 
+    if (!searcher) { THROW(ERR, "Invalid doc id: %i32", doc_id); }
+    return Searcher_Fetch_Doc(searcher, doc_id - start, score, 
         offset + start);
 }
 
@@ -80,10 +78,10 @@ DocVector*
 PolySearcher_fetch_doc_vec(PolySearcher *self, i32_t doc_id)
 {
     u32_t       tick       = PolyReader_sub_tick(self->starts, doc_id);
-    Searchable *searchable = (Searchable*)VA_Fetch(self->searchables, tick);
+    Searcher   *searcher   = (Searcher*)VA_Fetch(self->searchers, tick);
     i32_t       start      = I32Arr_Get(self->starts, tick);
-    if (!searchable) { THROW(ERR, "Invalid doc id: %i32", doc_id); }
-    return Searchable_Fetch_Doc_Vec(searchable, doc_id - start);
+    if (!searcher) { THROW(ERR, "Invalid doc id: %i32", doc_id); }
+    return Searcher_Fetch_Doc_Vec(searcher, doc_id - start);
 }
 
 i32_t 
@@ -97,9 +95,9 @@ PolySearcher_doc_freq(PolySearcher *self, const CharBuf *field, Obj *term)
 {
     u32_t i, max; 
     u32_t doc_freq = 0;
-    for (i = 0, max = VA_Get_Size(self->searchables); i < max; i++) {
-        Searchable *searchable = (Searchable*)VA_Fetch(self->searchables, i);
-        doc_freq += Searchable_Doc_Freq(searchable, field, term);
+    for (i = 0, max = VA_Get_Size(self->searchers); i < max; i++) {
+        Searcher *searcher = (Searcher*)VA_Fetch(self->searchers, i);
+        doc_freq += Searcher_Doc_Freq(searcher, field, term);
     }
     return doc_freq;
 }
@@ -120,22 +118,22 @@ PolySearcher_top_docs(PolySearcher *self, Query *query, u32_t num_wanted,
                       SortSpec *sort_spec)
 {
     Schema   *schema      = PolySearcher_Get_Schema(self);
-    VArray   *searchables = self->searchables;
+    VArray   *searchers   = self->searchers;
     I32Array *starts      = self->starts;
     HitQueue *hit_q       = sort_spec 
                           ? HitQ_new(schema, sort_spec, num_wanted)
                           : HitQ_new(NULL, NULL, num_wanted);
     u32_t     total_hits  = 0;
-    Compiler *compiler    = OBJ_IS_A(query, COMPILER) 
+    Compiler *compiler    = Query_Is_A(query, COMPILER) 
                           ? ((Compiler*)INCREF(query))
-                          : Query_Make_Compiler(query, (Searchable*)self,
+                          : Query_Make_Compiler(query, (Searcher*)self,
                                 Query_Get_Boost(query));
     u32_t i, max;
 
-    for (i = 0, max = VA_Get_Size(searchables); i < max; i++) {
-        Searchable *searchable = (Searchable*)VA_Fetch(searchables, i);
+    for (i = 0, max = VA_Get_Size(searchers); i < max; i++) {
+        Searcher   *searcher   = (Searcher*)VA_Fetch(searchers, i);
         i32_t       base       = I32Arr_Get(starts, i);
-        TopDocs    *top_docs   = Searchable_Top_Docs(searchable, 
+        TopDocs    *top_docs   = Searcher_Top_Docs(searcher, 
             (Query*)compiler, num_wanted, sort_spec);
         VArray     *sub_match_docs = TopDocs_Get_Match_Docs(top_docs);
         u32_t j, jmax;
@@ -165,22 +163,22 @@ PolySearcher_top_docs(PolySearcher *self, Query *query, u32_t num_wanted,
 
 void
 PolySearcher_collect(PolySearcher *self, Query *query, 
-                     HitCollector *collector)
+                     Collector *collector)
 {
     u32_t i, max;
-    VArray *const searchables = self->searchables;
+    VArray *const searchers = self->searchers;
     I32Array *starts = self->starts;
     
-    for (i = 0, max = VA_Get_Size(searchables); i < max; i++) {
+    for (i = 0, max = VA_Get_Size(searchers); i < max; i++) {
         i32_t start = I32Arr_Get(starts, i);
-        Searchable *searchable = (Searchable*)VA_Fetch(searchables, i);
+        Searcher *searcher = (Searcher*)VA_Fetch(searchers, i);
         OffsetCollector *offset_coll = OffsetColl_new(collector, start);
-        Searchable_Collect(searchable, query, (HitCollector*)offset_coll);
+        Searcher_Collect(searcher, query, (Collector*)offset_coll);
         DECREF(offset_coll);
     }
 }
 
-/* Copyright 2006-2009 Marvin Humphrey
+/* Copyright 2006-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
