@@ -3,21 +3,20 @@
 #include "KinoSearch/Util/ToolSet.h"
 
 #include "KinoSearch/Search/TermQuery.h"
-#include "KinoSearch/Schema.h"
-#include "KinoSearch/Search/Span.h"
 #include "KinoSearch/Index/DocVector.h"
 #include "KinoSearch/Index/SegReader.h"
 #include "KinoSearch/Index/PostingList.h"
-#include "KinoSearch/Index/PostingsReader.h"
+#include "KinoSearch/Index/PostingListReader.h"
 #include "KinoSearch/Index/TermVector.h"
+#include "KinoSearch/Plan/Schema.h"
 #include "KinoSearch/Search/Compiler.h"
-#include "KinoSearch/Search/Searchable.h"
+#include "KinoSearch/Search/Searcher.h"
 #include "KinoSearch/Search/Similarity.h"
+#include "KinoSearch/Search/Span.h"
 #include "KinoSearch/Search/TermScorer.h"
 #include "KinoSearch/Store/InStream.h"
 #include "KinoSearch/Store/OutStream.h"
 #include "KinoSearch/Util/Freezer.h"
-#include "KinoSearch/Util/I32Array.h"
 
 TermQuery*
 TermQuery_new(const CharBuf *field, const Obj *term)
@@ -71,7 +70,7 @@ TermQuery_equals(TermQuery *self, Obj *other)
 {
     TermQuery *evil_twin = (TermQuery*)other;
     if (evil_twin == self) return true;
-    if (!OBJ_IS_A(evil_twin, TERMQUERY)) return false;
+    if (!Obj_Is_A(other, TERMQUERY)) return false;
     if (self->boost != evil_twin->boost) return false;
     if (!CB_Equals(self->field, (Obj*)evil_twin->field)) return false;
     if (!Obj_Equals(self->term, evil_twin->term)) return false;
@@ -88,25 +87,25 @@ TermQuery_to_string(TermQuery *self)
 }
 
 Compiler*
-TermQuery_make_compiler(TermQuery *self, Searchable *searchable, float boost) 
+TermQuery_make_compiler(TermQuery *self, Searcher *searcher, float boost) 
 {
-    return (Compiler*)TermCompiler_new((Query*)self, searchable, boost);
+    return (Compiler*)TermCompiler_new((Query*)self, searcher, boost);
 }
 
 /******************************************************************/
 
 TermCompiler*
-TermCompiler_new(Query *parent, Searchable *searchable, float boost)
+TermCompiler_new(Query *parent, Searcher *searcher, float boost)
 {
     TermCompiler *self = (TermCompiler*)VTable_Make_Obj(TERMCOMPILER);
-    return TermCompiler_init(self, parent, searchable, boost);
+    return TermCompiler_init(self, parent, searcher, boost);
 }
 
 TermCompiler*
-TermCompiler_init(TermCompiler *self, Query *parent, Searchable *searchable, 
+TermCompiler_init(TermCompiler *self, Query *parent, Searcher *searcher, 
                   float boost)
 {
-    Schema     *schema  = Searchable_Get_Schema(searchable);
+    Schema     *schema  = Searcher_Get_Schema(searcher);
     TermQuery  *tparent = (TermQuery*)parent;
     Similarity *sim     = Schema_Fetch_Sim(schema, tparent->field);
 
@@ -114,12 +113,12 @@ TermCompiler_init(TermCompiler *self, Query *parent, Searchable *searchable,
     if (!sim) { sim = Schema_Get_Similarity(schema); }
 
     /* Init. */
-    Compiler_init((Compiler*)self, parent, searchable, sim, boost);
+    Compiler_init((Compiler*)self, parent, searcher, sim, boost);
     self->normalized_weight = 0.0f;
     self->query_norm_factor = 0.0f;
 
     /* Derive. */
-    self->idf = Sim_IDF(sim, searchable, tparent->field, tparent->term);
+    self->idf = Sim_IDF(sim, searcher, tparent->field, tparent->term);
     
     /* The score of any document is approximately equal to:
      *
@@ -135,7 +134,7 @@ TermCompiler_init(TermCompiler *self, Query *parent, Searchable *searchable,
     self->raw_weight = self->idf * self->boost;
 
     /* Make final preparations. */
-    Compiler_Normalize(self);
+    TermCompiler_Normalize(self);
 
     return self;
 }
@@ -145,7 +144,7 @@ TermCompiler_equals(TermCompiler *self, Obj *other)
 {
     TermCompiler *evil_twin = (TermCompiler*)other;
     if (!Compiler_equals((Compiler*)self, other)) return false;
-    if (!OBJ_IS_A(evil_twin, TERMCOMPILER)) return false;
+    if (!Obj_Is_A(other, TERMCOMPILER)) return false;
     if (self->idf != evil_twin->idf) return false;
     if (self->raw_weight != evil_twin->raw_weight) return false;
     if (self->query_norm_factor != evil_twin->query_norm_factor) return false;
@@ -207,10 +206,10 @@ TermCompiler_make_matcher(TermCompiler *self, SegReader *reader,
                           bool_t need_score)
 {
     TermQuery *tparent = (TermQuery*)self->parent;
-    PostingsReader *post_reader = (PostingsReader*)SegReader_Fetch(reader,
-        VTable_Get_Name(POSTINGSREADER));
-    PostingList *plist = post_reader 
-        ? PostReader_Posting_List(post_reader, tparent->field, tparent->term)
+    PostingListReader *plist_reader = (PostingListReader*)SegReader_Fetch(reader,
+        VTable_Get_Name(POSTINGLISTREADER));
+    PostingList *plist = plist_reader 
+        ? PListReader_Posting_List(plist_reader, tparent->field, tparent->term)
         : NULL;
 
     if (plist == NULL || PList_Get_Doc_Freq(plist) == 0) {
@@ -226,7 +225,7 @@ TermCompiler_make_matcher(TermCompiler *self, SegReader *reader,
 }
 
 VArray*
-TermCompiler_highlight_spans(TermCompiler *self, Searchable *searchable, 
+TermCompiler_highlight_spans(TermCompiler *self, Searcher *searcher, 
                              DocVector *doc_vec, const CharBuf *field)
 {
     TermQuery *const parent = (TermQuery*)self->parent;
@@ -234,7 +233,7 @@ TermCompiler_highlight_spans(TermCompiler *self, Searchable *searchable,
     TermVector *term_vector;
     I32Array *starts, *ends;
     u32_t i, max;
-    UNUSED_VAR(searchable);
+    UNUSED_VAR(searcher);
 
     if (!CB_Equals(parent->field, (Obj*)field)) return spans;
 
@@ -255,7 +254,7 @@ TermCompiler_highlight_spans(TermCompiler *self, Searchable *searchable,
     return spans;
 }
 
-/* Copyright 2006-2009 Marvin Humphrey
+/* Copyright 2006-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
