@@ -5,14 +5,14 @@
 #include "KinoSearch/Test/Analysis/TestPolyAnalyzer.h"
 #include "KinoSearch/Analysis/PolyAnalyzer.h"
 
-static ZombieCharBuf EN = ZCB_LITERAL("en");
-static ZombieCharBuf ES = ZCB_LITERAL("es");
 
 static void
 test_Dump_Load_and_Equals(TestBatch *batch)
 {
-    PolyAnalyzer *analyzer    = PolyAnalyzer_new((CharBuf*)&EN, NULL);
-    PolyAnalyzer *other       = PolyAnalyzer_new((CharBuf*)&ES, NULL);
+    CharBuf      *EN          = (CharBuf*)ZCB_WRAP_STR("en", 2);
+    CharBuf      *ES          = (CharBuf*)ZCB_WRAP_STR("es", 2);
+    PolyAnalyzer *analyzer    = PolyAnalyzer_new(EN, NULL);
+    PolyAnalyzer *other       = PolyAnalyzer_new(ES, NULL);
     Obj          *dump        = (Obj*)PolyAnalyzer_Dump(analyzer);
     Obj          *other_dump  = (Obj*)PolyAnalyzer_Dump(other);
     PolyAnalyzer *clone       = (PolyAnalyzer*)PolyAnalyzer_Load(other, dump);
@@ -45,17 +45,17 @@ test_Dump_Load_and_Equals(TestBatch *batch)
 void
 TestPolyAnalyzer_run_tests()
 {
-    TestBatch *batch = Test_new_batch("TestPolyAnalyzer", 7, NULL);
+    TestBatch *batch = TestBatch_new(7);
 
-    PLAN(batch);
+    TestBatch_Plan(batch);
 
     test_Dump_Load_and_Equals(batch);
 
-    batch->destroy(batch);
+    DECREF(batch);
 }
 
 
-/* Copyright 2005-2009 Marvin Humphrey
+/* Copyright 2005-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
