@@ -5,14 +5,13 @@
 #include "KinoSearch/Test/Analysis/TestStemmer.h"
 #include "KinoSearch/Analysis/Stemmer.h"
 
-static ZombieCharBuf EN = ZCB_LITERAL("en");
-static ZombieCharBuf ES = ZCB_LITERAL("es");
-
 static void
 test_Dump_Load_and_Equals(TestBatch *batch)
 {
-    Stemmer *stemmer     = Stemmer_new((CharBuf*)&EN);
-    Stemmer *other       = Stemmer_new((CharBuf*)&ES);
+    CharBuf *EN          = (CharBuf*)ZCB_WRAP_STR("en", 2); 
+    CharBuf *ES          = (CharBuf*)ZCB_WRAP_STR("es", 2); 
+    Stemmer *stemmer     = Stemmer_new(EN);
+    Stemmer *other       = Stemmer_new(ES);
     Obj     *dump        = (Obj*)Stemmer_Dump(stemmer);
     Obj     *other_dump  = (Obj*)Stemmer_Dump(other);
     Stemmer *clone       = (Stemmer*)Stemmer_Load(other, dump);
@@ -44,17 +43,17 @@ test_Dump_Load_and_Equals(TestBatch *batch)
 void
 TestStemmer_run_tests()
 {
-    TestBatch *batch = Test_new_batch("TestStemmer", 7, NULL);
+    TestBatch *batch = TestBatch_new(7);
 
-    PLAN(batch);
+    TestBatch_Plan(batch);
 
     test_Dump_Load_and_Equals(batch);
 
-    batch->destroy(batch);
+    DECREF(batch);
 }
 
 
-/* Copyright 2005-2009 Marvin Humphrey
+/* Copyright 2005-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
