@@ -1,3 +1,5 @@
+#define C_KINO_TESTQUERYPARSERLOGIC
+#define C_KINO_TESTQUERYPARSER
 #include "KinoSearch/Util/ToolSet.h"
 #include <stdarg.h>
 #include <string.h>
@@ -9,11 +11,11 @@
 #include "KinoSearch/Test/TestUtils.h"
 #include "KinoSearch/Analysis/Analyzer.h"
 #include "KinoSearch/Analysis/Tokenizer.h"
-#include "KinoSearch/Doc.h"
-#include "KinoSearch/Indexer.h"
-#include "KinoSearch/QueryParser.h"
-#include "KinoSearch/Searcher.h"
+#include "KinoSearch/Document/Doc.h"
+#include "KinoSearch/Index/Indexer.h"
 #include "KinoSearch/Search/Hits.h"
+#include "KinoSearch/Search/IndexSearcher.h"
+#include "KinoSearch/Search/QueryParser.h"
 #include "KinoSearch/Search/TermQuery.h"
 #include "KinoSearch/Search/PhraseQuery.h"
 #include "KinoSearch/Search/LeafQuery.h"
@@ -612,10 +614,10 @@ S_create_index()
     Indexer    *indexer = Indexer_new(schema, (Obj*)folder, NULL, 0);
     u32_t i, max;
 
+    CharBuf *field = (CharBuf*)ZCB_WRAP_STR("content", 7);
     for (i = 0, max = VA_Get_Size(doc_set); i < max; i++) {
-        static CharBuf field = ZCB_LITERAL("content");
         Doc *doc = Doc_new(NULL, 0);
-        Doc_Store(doc, &field, VA_Fetch(doc_set, i));
+        Doc_Store(doc, field, VA_Fetch(doc_set, i));
         Indexer_Add_Doc(indexer, doc, 1.0f);
         DECREF(doc);
     }
@@ -633,18 +635,18 @@ void
 TestQPLogic_run_tests()
 {
     u32_t i;
-    TestBatch   *batch = Test_new_batch("TestQueryParserLogic", 178, NULL);
-    Folder      *folder       = S_create_index();
-    Searcher    *searcher     = Searcher_new((Obj*)folder);
-    QueryParser *or_parser    = QParser_new(Searcher_Get_Schema(searcher), 
+    TestBatch     *batch      = TestBatch_new(178);
+    Folder        *folder     = S_create_index();
+    IndexSearcher *searcher   = IxSearcher_new((Obj*)folder);
+    QueryParser   *or_parser  = QParser_new(IxSearcher_Get_Schema(searcher), 
         NULL, NULL, NULL);
-    static  ZombieCharBuf AND = ZCB_LITERAL("AND");
-    QueryParser *and_parser   = QParser_new(Searcher_Get_Schema(searcher), 
-        NULL, (CharBuf*)&AND, NULL);
+    ZombieCharBuf *AND        = ZCB_WRAP_STR("AND", 3);
+    QueryParser   *and_parser = QParser_new(IxSearcher_Get_Schema(searcher), 
+        NULL, (CharBuf*)AND, NULL);
     QParser_Set_Heed_Colons(or_parser, true);
     QParser_Set_Heed_Colons(and_parser, true);
 
-    PLAN(batch);
+    TestBatch_Plan(batch);
 
     /* Run logical tests with default boolop of OR. */
     for (i = 0; logical_test_funcs[i] != NULL; i++) {
@@ -652,7 +654,7 @@ TestQPLogic_run_tests()
         TestQueryParser *test_case = test_func(BOOLOP_OR);
         Query *tree     = QParser_Tree(or_parser, test_case->query_string);
         Query *parsed   = QParser_Parse(or_parser, test_case->query_string);
-        Hits  *hits     = Searcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
+        Hits  *hits     = IxSearcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
 
         ASSERT_TRUE(batch, Query_Equals(tree, (Obj*)test_case->tree),
             "tree() OR   %s", (char*)CB_Get_Ptr8(test_case->query_string));
@@ -670,7 +672,7 @@ TestQPLogic_run_tests()
         TestQueryParser *test_case = test_func(BOOLOP_AND);
         Query *tree     = QParser_Tree(and_parser, test_case->query_string);
         Query *parsed   = QParser_Parse(and_parser, test_case->query_string);
-        Hits  *hits     = Searcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
+        Hits  *hits     = IxSearcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
 
         ASSERT_TRUE(batch, Query_Equals(tree, (Obj*)test_case->tree),
             "tree() AND   %s", (char*)CB_Get_Ptr8(test_case->query_string));
@@ -687,7 +689,7 @@ TestQPLogic_run_tests()
         kino_TestQPLogic_prune_test_t test_func = prune_test_funcs[i];
         TestQueryParser *test_case = test_func();
         CharBuf *qstring = test_case->tree 
-                         ? Obj_To_String(test_case->tree)
+                         ? Query_To_String(test_case->tree)
                          : CB_new_from_trusted_utf8("(NULL)", 6);
         Query *tree = test_case->tree;
         Query *wanted = test_case->expanded;
@@ -698,7 +700,7 @@ TestQPLogic_run_tests()
         ASSERT_TRUE(batch, Query_Equals(pruned, (Obj*)wanted),
             "prune()   %s", (char*)CB_Get_Ptr8(qstring));
         expanded = QParser_Expand(or_parser, pruned);
-        hits = Searcher_Hits(searcher, (Obj*)expanded, 0, 10, NULL);
+        hits = IxSearcher_Hits(searcher, (Obj*)expanded, 0, 10, NULL);
         ASSERT_INT_EQ(batch, Hits_Total_Hits(hits), test_case->num_hits,
             "hits:    %s", (char*)CB_Get_Ptr8(qstring));
 
@@ -713,9 +715,9 @@ TestQPLogic_run_tests()
     DECREF(or_parser);
     DECREF(searcher);
     DECREF(folder);
-    batch->destroy(batch);
+    DECREF(batch);
 }
-/* Copyright 2005-2009 Marvin Humphrey
+/* Copyright 2005-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
