@@ -1,3 +1,5 @@
+#define C_KINO_TESTQUERYPARSERSYNTAX
+#define C_KINO_TESTQUERYPARSER
 #include "KinoSearch/Util/ToolSet.h"
 #include <stdarg.h>
 #include <string.h>
@@ -6,9 +8,9 @@
 #include "KinoSearch/Test/TestQueryParserSyntax.h"
 #include "KinoSearch/Test/TestQueryParser.h"
 #include "KinoSearch/Test/TestUtils.h"
-#include "KinoSearch/QueryParser.h"
-#include "KinoSearch/Searcher.h"
 #include "KinoSearch/Search/Hits.h"
+#include "KinoSearch/Search/IndexSearcher.h"
+#include "KinoSearch/Search/QueryParser.h"
 #include "KinoSearch/Search/TermQuery.h"
 #include "KinoSearch/Search/PhraseQuery.h"
 #include "KinoSearch/Search/LeafQuery.h"
@@ -224,21 +226,21 @@ void
 TestQPSyntax_run_tests(Folder *index)
 {
     u32_t i;
-    TestBatch   *batch = Test_new_batch("TestQueryParserSyntax", 48, NULL);
-    Searcher    *searcher     = Searcher_new((Obj*)index);
-    QueryParser *qparser      = QParser_new(Searcher_Get_Schema(searcher), 
+    TestBatch     *batch      = TestBatch_new(48);
+    IndexSearcher *searcher   = IxSearcher_new((Obj*)index);
+    QueryParser   *qparser    = QParser_new(IxSearcher_Get_Schema(searcher), 
         NULL, NULL, NULL);
     QParser_Set_Heed_Colons(qparser, true);
 
-    PLAN(batch);
+    TestBatch_Plan(batch);
 
     for (i = 0; leaf_test_funcs[i] != NULL; i++) {
         kino_TestQPSyntax_test_t test_func = leaf_test_funcs[i];
-        TestQueryParser *test_case = test_func(i);
+        TestQueryParser *test_case = test_func();
         Query *tree     = QParser_Tree(qparser, test_case->query_string);
         Query *expanded = QParser_Expand_Leaf(qparser, test_case->tree);
         Query *parsed   = QParser_Parse(qparser, test_case->query_string);
-        Hits  *hits     = Searcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
+        Hits  *hits     = IxSearcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
 
         ASSERT_TRUE(batch, Query_Equals(tree, (Obj*)test_case->tree),
             "tree()    %s", (char*)CB_Get_Ptr8(test_case->query_string));
@@ -255,10 +257,10 @@ TestQPSyntax_run_tests(Folder *index)
 
     for (i = 0; syntax_test_funcs[i] != NULL; i++) {
         kino_TestQPSyntax_test_t test_func = syntax_test_funcs[i];
-        TestQueryParser *test_case = test_func(i);
+        TestQueryParser *test_case = test_func();
         Query *tree   = QParser_Tree(qparser, test_case->query_string);
         Query *parsed = QParser_Parse(qparser, test_case->query_string);
-        Hits  *hits   = Searcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
+        Hits  *hits   = IxSearcher_Hits(searcher, (Obj*)parsed, 0, 10, NULL);
 
         ASSERT_TRUE(batch, Query_Equals(tree, (Obj*)test_case->tree),
             "tree()    %s", (char*)CB_Get_Ptr8(test_case->query_string));
@@ -270,12 +272,12 @@ TestQPSyntax_run_tests(Folder *index)
         DECREF(test_case);
     }
 
-    batch->destroy(batch);
+    DECREF(batch);
     DECREF(searcher);
     DECREF(qparser);
 }
 
-/* Copyright 2005-2009 Marvin Humphrey
+/* Copyright 2005-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
