@@ -3,14 +3,14 @@
 #define C_KINO_INVERTERENTRY
 #include "xs/XSBind.h"
 #include "KinoSearch/Index/Inverter.h"
-#include "KinoSearch/Doc.h"
-#include "KinoSearch/FieldType.h"
-#include "KinoSearch/FieldType/BlobType.h"
-#include "KinoSearch/FieldType/NumericType.h"
-#include "KinoSearch/FieldType/TextType.h"
+#include "KinoSearch/Document/Doc.h"
 #include "KinoSearch/Index/Segment.h"
-#include "KinoSearch/Obj/ByteBuf.h"
-#include "KinoSearch/Schema.h"
+#include "KinoSearch/Object/ByteBuf.h"
+#include "KinoSearch/Plan/FieldType.h"
+#include "KinoSearch/Plan/BlobType.h"
+#include "KinoSearch/Plan/NumericType.h"
+#include "KinoSearch/Plan/Schema.h"
+#include "KinoSearch/Plan/TextType.h"
 
 static kino_InverterEntry*
 S_fetch_entry(kino_Inverter *self, HE *hash_entry)
@@ -22,22 +22,22 @@ S_fetch_entry(kino_Inverter *self, HE *hash_entry)
     char *key = HeKLEN(hash_entry) == HEf_SVKEY
               ? SvPV(HeKEY_sv(hash_entry), key_len) 
               : ((key_len = HeKLEN(hash_entry)), HeKEY(hash_entry));
-    kino_ZombieCharBuf field = kino_ZCB_make_str(key, key_len);
+    kino_ZombieCharBuf *field = KINO_ZCB_WRAP_STR(key, key_len);
     chy_i32_t field_num 
-        = Kino_Seg_Field_Num(self->segment, (kino_CharBuf*)&field);
+        = Kino_Seg_Field_Num(self->segment, (kino_CharBuf*)field);
 
     if (!field_num) {
         /* This field seems not to be in the segment yet.  Try to find it in
          * the Schema. */
-        if (!Kino_Schema_Fetch_Type(schema, (kino_CharBuf*)&field)) {
+        if (!Kino_Schema_Fetch_Type(schema, (kino_CharBuf*)field)) {
             /* OK, it could be that the field name contains non-ASCII
              * characters, but the hash key is encoded as Latin 1.  So, we
              * force hash key into an SV and ask for a UTF-8 PV.  This is
              * less efficient, so field names really ought to be ASCII. */
             SV *key_sv = HeSVKEY_force(hash_entry);
             key = SvPVutf8(key_sv, key_len);
-            Kino_ZCB_Assign_Str(&field, key, key_len);
-            if (!Kino_Schema_Fetch_Type(schema, (kino_CharBuf*)&field)) {
+            Kino_ZCB_Assign_Str(field, key, key_len);
+            if (!Kino_Schema_Fetch_Type(schema, (kino_CharBuf*)field)) {
                 /* We've truly failed to find the field.  The user must
                  * not have spec'd it. */
                 THROW(KINO_ERR, "Unknown field name: '%s'", key);
@@ -45,7 +45,7 @@ S_fetch_entry(kino_Inverter *self, HE *hash_entry)
         }
 
         /* The field is in the Schema.  Get a field num from the Segment. */
-        field_num = Kino_Seg_Add_Field(self->segment, (kino_CharBuf*)&field);
+        field_num = Kino_Seg_Add_Field(self->segment, (kino_CharBuf*)field);
     }
 
     {
@@ -53,7 +53,7 @@ S_fetch_entry(kino_Inverter *self, HE *hash_entry)
             = (kino_InverterEntry*)Kino_VA_Fetch(self->entry_pool, field_num);
         if (!entry) {
             entry 
-                = kino_InvEntry_new(schema, (kino_CharBuf*)&field, field_num);
+                = kino_InvEntry_new(schema, (kino_CharBuf*)field, field_num);
             Kino_VA_Store(self->entry_pool, field_num, (kino_Obj*)entry);
         }
         return entry;
@@ -63,8 +63,8 @@ S_fetch_entry(kino_Inverter *self, HE *hash_entry)
 void
 kino_Inverter_invert_doc(kino_Inverter *self, kino_Doc *doc)
 {
-    HV          *const fields = Kino_Doc_Get_Fields(doc);
-    I32          num_keys     = hv_iterinit(fields);
+    HV  *const fields = (HV*)Kino_Doc_Get_Fields(doc);
+    I32  num_keys     = hv_iterinit(fields);
 
     /* Prepare for the new doc. */
     Kino_Inverter_Set_Doc(self, doc);
@@ -83,13 +83,15 @@ kino_Inverter_invert_doc(kino_Inverter *self, kino_Doc *doc)
             case kino_FType_TEXT: {
                 STRLEN val_len;
                 char *val_ptr = SvPVutf8(value_sv, val_len);
-                Kino_ViewCB_Assign_Str(inv_entry->value, val_ptr, val_len);
+                kino_ViewCharBuf *value = (kino_ViewCharBuf*)inv_entry->value;
+                Kino_ViewCB_Assign_Str(value, val_ptr, val_len);
                 break;
             }
             case kino_FType_BLOB: {
                 STRLEN val_len;
                 char *val_ptr = SvPV(value_sv, val_len);
-                Kino_ViewBB_Assign_Bytes(inv_entry->value, val_ptr, val_len);
+                kino_ViewByteBuf *value = (kino_ViewByteBuf*)inv_entry->value;
+                Kino_ViewBB_Assign_Bytes(value, val_ptr, val_len);
                 break;
             }
             case kino_FType_INT32: {
@@ -123,7 +125,7 @@ kino_Inverter_invert_doc(kino_Inverter *self, kino_Doc *doc)
     }
 }
 
-/* Copyright 2005-2009 Marvin Humphrey
+/* Copyright 2005-2010 Marvin Humphrey
  *
  * This program is free software; you can redistribute it and/or modify
  * under the same terms as Perl itself.
